==> limny-3.0.0.tar.bz2: limny-3.0.0/incs/widget.class.php <==
<?php

/*
 * widget.class.php
 *
 * @copyright     Copyright 2009-2011 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

class Widget
{
	function load_widgets($position)
	{
		global $db;
		
		$class['user'] = new User;
		$class['language'] = new Language;
		
		$widgets = '';
		$query = $db->select('*', 'widgets', 'WHERE position=\'' . add_slashes($position) . '\' ORDER BY id ASC');
		while($widget = $db->fetch_array($query))
		{
			if($widget['languages'] == 'all' || in_array($class['language']->language, explode(',', $widget['languages'])))
			{
				if($widget['roles'] == 'all' || in_array((($class['user']->is_authorized()) ? $class['user']->user_get_info('role') : null), explode(',', $widget['roles'])))
				{
					$widgets .= $this->get_widget($widget);
				}
			}
		}
		return $widgets;
	}
	
	function get_widget($widget)
	{
		$widget['title'] = eval_this($widget['title']);
		$widget['content'] = eval_this($widget['content']);
		
		$class['config'] = new Config;
		
		if(empty($widget['app']))
		{
			$widget['title'] = strip_tags($widget['title']);
			$widget['content'] = strip_tags($widget['content'], $class['config']->strip_tags);
		}
		
		if(empty($widget['title']))
		{
			return $widget['content'];
		}else{
			if(!empty($widget['content']))
			{
				ob_start();
				include(__PATH__ . '/themes/' . $class['config']->theme . '/widget.tpl');
				$contents = ob_get_contents();
				ob_end_clean();
				return $contents;
			}
		}
	}
}

?>

==> limny-3.2.1.tar.bz2: limny-3.2.1/incs/widget.class.php <==
<?php

/*
 * widget.class.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

class Widget
{
	function load_widgets($position)
	{
		global $db;
		
		$class['user'] = new User;
		$class['language'] = new Language;
		
		$widgets = '';
		$result = $db->select('widgets', '*', array('position' => '=\'' . $db->escape($position) . '\'', 'ORDER BY', 'id' => 'ASC'));
		while ($widget = $db->fetch_assoc($result))
		{
			if ($widget['languages'] == 'all' || in_array($class['language']->language, explode(',', $widget['languages'])))
			{
				if ($widget['roles'] == 'all' || in_array((($class['user']->is_authorized()) ? $class['user']->user_get_info('role') : NULL), explode(',', $widget['roles'])))
				{
					$widgets .= $this->get_widget($widget);
				}
			}
		}
		
		return $widgets;
	}
	
	function get_widget($widget)
	{
		$widget['title'] = eval_this($widget['title']);
		$widget['content'] = eval_this($widget['content']);
		
		$class['config'] = new Config;
		
		if (empty($widget['app']))
		{
			$widget['title'] = strip_tags($widget['title']);
			$widget['content'] = strip_tags($widget['content'], $class['config']->strip_tags);
		}
		
		if (empty($widget['title']))
		{
			return $widget['content'];
		}
		else
		{
			if (!empty($widget['content']))
			{
				ob_start();
				include(__PATH__ . '/themes/' . $class['config']->theme . '/widget.tpl');
				$contents = ob_get_contents();
				ob_end_clean();
				
				return $contents;
			}
		}
	}
}

?>
